/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.cdc.common.route;

import java.io.Serializable;

/** Definition of a routing rule with replacement symbol. */
public class RouteRule implements Serializable {

    private static final long serialVersionUID = 1L;

    public RouteRule(String sourceTable, String sinkTable) {
        this(sourceTable, sinkTable, null);
    }

    public RouteRule(String sourceTable, String sinkTable, String replaceSymbol) {
        this.sourceTable = sourceTable;
        this.sinkTable = sinkTable;
        this.replaceSymbol = replaceSymbol;
    }

    public String sourceTable;
    public String sinkTable;
    public String replaceSymbol;
}
